OGRSQLDriver objects are created by [OGRSQL()] and used to select the correct method in [dbConnect()]. They are a superclass of the [DBIDriver-class] class, and used purely for dispatch.
OGRSQLDriver objects are created by [OGRSQL()] and used to select the correct method in [dbConnect()]. They are a superclass of the [DBIDriver-class] class, and used purely for dispatch.